@@ -1,6 +1,8 @@
 # codin: utf-8
 import os
+import sys
 import numpy as np
+from Cython.Build import cythonize
 
 libraries = []
 if os.name == 'posix':
@@ -25,6 +27,9 @@ def configuration(parent_package='', top_path=None):
     config.add_subpackage('search')
     config.add_subpackage('utils')
 
+    if 'sdist' not in sys.argv:
+        config.ext_modules = cythonize(config.ext_modules)
+
     return config
 
 if __name__ == "__main__":
